@@ -30,8 +30,13 @@ FmakeDB<-function(LF2, kind =1, Iendian=1, BIGLONG=FALSE)
         
         for(j in 1:length(sinfo))
           {
-            REC = sinfo[[j]]
-            N = N + 1
+              REC = sinfo[[j]]
+              if(is.null(REC$DATTIM[[ 'msec' ]] )) REC$DATTIM$msec=0
+                 if(is.null(REC$DATTIM[['dt']] )) REC$DATTIM$dt=REC$dt
+                    
+                    
+                    
+                    N = N + 1
             ADB$fn[N] = REC$fn
             ADB$sta[N] = REC$sta
             ADB$comp[N] = REC$comp
